@@ -10,7 +10,7 @@ require 'puppet/util/psych_support'
 class Puppet::Indirector::Request
   include Puppet::Util::PsychSupport
 
-  attr_accessor :key, :method, :options, :instance, :node, :ip, :authenticated, :ignore_cache, :ignore_terminus
+  attr_accessor :key, :method, :options, :instance, :node, :ip, :authenticated, :ignore_cache, :ignore_cache_save, :ignore_terminus
 
   attr_accessor :server, :port, :uri, :protocol
 
@@ -18,7 +18,7 @@ class Puppet::Indirector::Request
 
   # trusted_information is specifically left out because we can't serialize it
   # and keep it "trusted"
-  OPTION_ATTRIBUTES = [:ip, :node, :authenticated, :ignore_terminus, :ignore_cache, :instance, :environment]
+  OPTION_ATTRIBUTES = [:ip, :node, :authenticated, :ignore_terminus, :ignore_cache, :ignore_cache_save, :instance, :environment]
 
   # Is this an authenticated request?
   def authenticated?
@@ -50,6 +50,10 @@ class Puppet::Indirector::Request
     ignore_cache
   end
 
+  def ignore_cache_save?
+    ignore_cache_save
+  end
+
   def ignore_terminus?
     ignore_terminus
   end
@@ -193,23 +197,19 @@ class Puppet::Indirector::Request
     end
 
     # ... Fall back onto the default server.
-    begin
-      bound_server = Puppet.lookup(:server)
-    rescue
+     bound_server = Puppet.lookup(:server) do
       if primary_server = Puppet.settings[:server_list][0]
-        bound_server = primary_server[0]
+        primary_server[0]
       else
-        bound_server = Puppet.settings[:server]
+        Puppet.settings[:server]
       end
     end
 
-    begin
-      bound_port = Puppet.lookup(:serverport)
-    rescue
+    bound_port = Puppet.lookup(:serverport) do
       if primary_server = Puppet.settings[:server_list][0]
-        bound_port = primary_server[1]
+        primary_server[1]
       else
-        bound_port = Puppet.settings[:masterport]
+        Puppet.settings[:masterport]
       end
     end
     self.server = default_server || bound_server
